PigeonSensorTypeDevice class
Properties
-
flashAvailable
↔ bool
-
A Boolean value that indicates whether the flash is currently available for use.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
iso
↔ double
-
The current exposure ISO value.
getter/setter pair
-
name
↔ String
-
A localized device name for display in the user interface.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sensorType
↔ PigeonSensorType
-
getter/setter pair
-
uid
↔ String
-
An identifier that uniquely identifies the device.
getter/setter pair